pub struct ClientCredentialsFlow { /* private fields */ }Expand description
Orchestrates the Client Credentials Flow (RFC 6749 Section 4.4).
This flow is used by clients to obtain an access token outside of the context of a user. This is typically used for client-to-client communication.
Implementations
Sourceimpl ClientCredentialsFlow
impl ClientCredentialsFlow