pub struct DeviceAuthorizationResponse {
pub device_code: String,
pub user_code: String,
pub verification_uri: String,
pub verification_uri_complete: Option<String>,
pub expires_in: u64,
pub interval: Option<u64>,
}Expand description
Represents the response from the device authorization endpoint. Defined in RFC 8628 Section 3.2.
Fields
device_code: StringThe device verification code.
user_code: StringThe end-user verification code.
verification_uri: StringThe end-user verification URI on the authorization server.
verification_uri_complete: Option<String>A verification URI that includes the “user_code” (or other information) to optimize the end-user interaction.
expires_in: u64The lifetime in seconds of the “device_code” and “user_code”.
interval: Option<u64>The minimum amount of time in seconds that the client SHOULD wait between polling requests to the token endpoint.